@@ -83,19 +83,6 @@ def add_loader(name, loader):
         LOADERS[name] = loader
 
 
-def file_loader(file_type, pattern):
-    if file_type.lower() == 'rdt':
-        return rdt.Loader(pattern)
-    elif file_type.lower() == 'gpm':
-        return GPM(pattern)
-    elif file_type.lower() == 'earthnetworks':
-        return earth_networks.Loader(pattern)
-    elif file_type.lower() == 'eida50':
-        return satellite.EIDA50(pattern)
-    else:
-        raise Exception("unrecognised file_type: {}".format(file_type))
-
-
 def load_coastlines():
     return xs_ys(iterlines(
             cartopy.feature.COASTLINE.geometries()))
