@@ -1,6 +1,6 @@
 
 
-class Observer(object):
+class Observable(object):
     def __init__(self):
         self.subscribers = []
 
